@@ -63,10 +63,10 @@ class QSNMPServer():
                 return version, community, oids
 
             def datagramReceived(self, data, addr):
-                _q_s.logs.info({'server': 'snmp_server', 'action': 'connection', 'status': 'fail', 'dest_ip': addr[0], 'dest_port': addr[1], 'src_ip': _q_s.ip, 'src_port': _q_s.port})
+                _q_s.logs.info({'server': 'snmp_server', 'action': 'connection', 'status': 'fail', 'src_ip': addr[0], 'src_port': addr[1], 'dest_ip': _q_s.ip, 'dest_port': _q_s.port})
                 version, community, oids = self.parse_snmp(data)
                 if version or community or oids:
-                    _q_s.logs.info({'server': 'snmp_server', 'action': 'query', 'status': 'success', 'dest_ip': addr[0], 'dest_port': addr[1], 'src_ip': _q_s.ip, 'src_port': _q_s.port, 'version': version, 'community': community, 'oids': oids})
+                    _q_s.logs.info({'server': 'snmp_server', 'action': 'query', 'status': 'success', 'src_ip': addr[0], 'src_port': addr[1], 'dest_ip': _q_s.ip, 'dest_port': _q_s.port, 'version': version, 'community': community, 'oids': oids})
                     self.transport.write('Error', addr)
 
                 self.transport.loseConnection()
@@ -91,7 +91,7 @@ class QSNMPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info({'server': 'snmp_server', 'action': 'process', 'status': status, 'dest_ip': self.ip, 'dest_port': self.port})
+            self.logs.info({'server': 'snmp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'dest_ip': self.ip, 'dest_port': self.port})
 
             if status == 'success':
                 return True
@@ -111,14 +111,13 @@ class QSNMPServer():
 
     def test_server(self, ip=None, port=None, username=None, password=None):
         try:
+
             from pysnmp.hlapi import (getCmd, SnmpEngine, CommunityData, UdpTransportTarget, ContextData, ObjectType, ObjectIdentity,)
             _ip = ip or self.ip
             _port = port or self.port
-            _username = username or self.username
-            _password = password or self.password
-            g = getCmd(SnmpEngine(), CommunityData('public'), UdpTransportTarget((_ip, _port)), ContextData(), ObjectType(ObjectIdentity('1.1.1.1.1.1.1.1.111.1.1.1.1')))
+            g = getCmd(SnmpEngine(), CommunityData('public'), UdpTransportTarget((_ip, _port)), ContextData(), ObjectType(ObjectIdentity('1.3.6.1.4.1.9.9.618.1.4.1.0')))
             errorIndication, errorStatus, errorIndex, varBinds = next(g)
-        except BaseException:
+        except Exception as e:
             pass
 
 
