@@ -1,5 +1,7 @@
 import honeypots
 from time import sleep
+from pkg_resources import get_distribution
+print("Version: ", get_distribution('honeypots').version)
 for server, cls in honeypots.__dict__.items():
     if server.endswith('Server'):
         print("Start testing {}".format(server))
